==> datatables-core-0.10.1-sources.jar: com/github/dandelion/datatables/core/util/JavascriptUtils.java <==
/*
 * [The "BSD licence"]
 * Copyright (c) 2013-2014 Dandelion
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Dandelion nor the names of its contributors 
 * may be used to endorse or promote products derived from this software 
 * without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.github.dandelion.datatables.core.util;

import java.util.Collection;
import java.util.Iterator;

public class JavascriptUtils {

	public final static char NEWLINE = '\n';
	public final static String INDENT = "   ";
	
	/**
	 * <p>
	 * Converts a collection of Strings into a Javascript array.
	 * 
	 * <p>
	 * For example, the following collection:
	 * {@code ("strint1", "string2", "string3")} will be converted to:
	 * {@code ['strint1', 'string2', 'string3']}
	 * 
	 * @param collection
	 *            The collection of Strings to convert into a Javascript array.
	 * @return a String representing a Javascript array.
	 */
	public static String toArray(Collection<String> collection){
		StringBuilder sb = new StringBuilder("[");

		Iterator<String> it = collection.iterator();
		while(it.hasNext()){
			sb.append("'");
			sb.append(it.next());
			sb.append("'");
			if(it.hasNext()){
				sb.append(",");
			}
		}
		sb.append("]");
		
		return sb.toString();
	}
}

==> datatables-core-1.1.0-sources.jar: com/github/dandelion/datatables/core/util/JavascriptUtils.java <==
/*
 * [The "BSD licence"]
 * Copyright (c) 2013-2015 Dandelion
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Dandelion nor the names of its contributors 
 * may be used to endorse or promote products derived from this software 
 * without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.github.dandelion.datatables.core.util;

import java.util.Collection;
import java.util.Iterator;

public final class JavascriptUtils {

   /**
    * <p>
    * Converts a collection of Strings into a Javascript array.
    * 
    * <p>
    * For example, the following collection:
    * {@code ("strint1", "string2", "string3")} will be converted to:
    * {@code ['strint1', 'string2', 'string3']}
    * 
    * @param collection
    *           The collection of Strings to convert into a Javascript array.
    * @return a String representing a Javascript array.
    */
   public static String toArray(Collection<String> collection) {
      StringBuilder sb = new StringBuilder("[");

      Iterator<String> it = collection.iterator();
      while (it.hasNext()) {
         sb.append("'");
         sb.append(it.next());
         sb.append("'");
         if (it.hasNext()) {
            sb.append(",");
         }
      }
      sb.append("]");

      return sb.toString();
   }

   /**
    * <p>
    * Suppress default constructor for noninstantiability.
    * </p>
    */
   private JavascriptUtils() {
      throw new AssertionError();
   }
}
